diff --git a/MPF.Check/MPF.Check.csproj b/MPF.Check/MPF.Check.csproj
index 872fb667..70c38b89 100644
--- a/MPF.Check/MPF.Check.csproj
+++ b/MPF.Check/MPF.Check.csproj
@@ -11,12 +11,18 @@
Copyright (c)2019-2021
https://github.com/SabreTools/MPF
1.18
- 1.18
- 1.18
+ $(Version)
+ $(Version)
true
true
+
+ $(Version)-{chash:8}
+ true
+ false
+
+
@@ -25,6 +31,7 @@
runtime; compile; build; native; analyzers; buildtransitive
+
diff --git a/MPF.Library/MPF.Library.csproj b/MPF.Library/MPF.Library.csproj
index ce2ddc0b..2254c921 100644
--- a/MPF.Library/MPF.Library.csproj
+++ b/MPF.Library/MPF.Library.csproj
@@ -9,13 +9,19 @@
Copyright (c)2019-2021
https://github.com/SabreTools/MPF
1.18
- 1.18
- 1.18
+ $(Version)
+ $(Version)
true
true
true
+
+ $(Version)-{chash:8}
+ true
+ false
+
+
NET_FRAMEWORK
@@ -73,6 +79,7 @@
+
diff --git a/MPF/MPF.csproj b/MPF/MPF.csproj
index 91cb6302..bcd4a8e9 100644
--- a/MPF/MPF.csproj
+++ b/MPF/MPF.csproj
@@ -14,17 +14,24 @@
Copyright (c)2019-2021
https://github.com/SabreTools/MPF
1.18
- 1.18
- 1.18
+ $(Version)
+ $(Version)
true
true
+
+ $(Version)-{chash:8}
+ true
+ false
+
+
runtime; compile; build; native; analyzers; buildtransitive
+
diff --git a/MPF/Windows/MainWindow.xaml.cs b/MPF/Windows/MainWindow.xaml.cs
index 6a8b2b9f..fc4e2565 100644
--- a/MPF/Windows/MainWindow.xaml.cs
+++ b/MPF/Windows/MainWindow.xaml.cs
@@ -820,7 +820,9 @@ namespace MPF.Windows
+ $"{Environment.NewLine}Supports DiscImageCreator, Aaru, and DD for Windows."
+ $"{Environment.NewLine}Originally created to help the Redump project."
+ $"{Environment.NewLine}"
- + $"{Environment.NewLine}Thanks to everyone who has supported this project!";
+ + $"{Environment.NewLine}Thanks to everyone who has supported this project!"
+ + $"{Environment.NewLine}"
+ + $"{Environment.NewLine}Version {Tools.GetCurrentVersion()}";
LogOutput.SecretLogLn(aboutText);
MessageBox.Show(aboutText, "About", MessageBoxButton.OK, MessageBoxImage.Information);
diff --git a/MPF.Library/Utilities/Tools.cs b/MPF.Library/Utilities/Tools.cs
index 41b7fcc7..763dc8fd 100644
--- a/MPF.Library/Utilities/Tools.cs
+++ b/MPF.Library/Utilities/Tools.cs
@@ -83,7 +83,8 @@ namespace MPF.Utilities
public static (bool different, string message, string url) CheckForNewVersion()
{
// Get current assembly version
- string version = GetCurrentVersion();
+ var assemblyVersion = Assembly.GetEntryAssembly().GetName().Version;
+ string version = $"{assemblyVersion.Major}.{assemblyVersion.Minor}" + (assemblyVersion.Build != 0 ? $".{assemblyVersion.Build}" : string.Empty);
// Get the latest tag from GitHub
using (var client = new RedumpWebClient())
@@ -102,12 +103,12 @@ namespace MPF.Utilities
}
///
/// Get the current assembly version formatted as a string
///
- private static string GetCurrentVersion()
+ public static string GetCurrentVersion()
{
- var assemblyVersion = Assembly.GetEntryAssembly().GetName().Version;
- return $"{assemblyVersion.Major}.{assemblyVersion.Minor}" + (assemblyVersion.Build != 0 ? $".{assemblyVersion.Build}" : string.Empty);
+ var assemblyVersion = Attribute.GetCustomAttribute(Assembly.GetEntryAssembly(), typeof(AssemblyInformationalVersionAttribute)) as AssemblyInformationalVersionAttribute;
+ return assemblyVersion.InformationalVersion;
}
#endregion
@@ -102,12 +103,12 @@ namespace MPF.Utilities
}
///
- /// Get the current assembly version formatted as a string
+ /// Get the current informational version formatted as a string
///